@@ -3,7 +3,7 @@ import os
 from googlesheettranslate.main import GoogleTranslationSheet
 
 ROOT = os.path.join(os.path.dirname(__file__))
-builder = GoogleTranslationSheet().builderOutputTarget(ROOT).builderFromExcel("emp-translation.xlsx").builderTransformers("i18n")
+builder = GoogleTranslationSheet().builderOutputTarget(ROOT).builderFromExcel("emp-translation.xlsx").builderTransformers("py")
 builder.GetReader().overrideFileFormat("__i{}.json", True)
 builder.run("EN")
 builder.run("ZH")
